# OIDCAuthURI

A specific path that will be used in included_paths/excluded_paths for authentication.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**path** | **str** | A specific path that will be used in included_paths/excluded_paths for authentication. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


